DateFields class abstract Dates

Localized date and time related texts.

Constructors

DateFields(CommonLocaleData cld)
const

Properties

cld CommonLocaleData
Parent CommonLocaleData
final
day DateFieldFullData
no setter
dayOfYear MultiLength
no setter
dayperiod MultiLength
no setter
era MultiLength
no setter
friday DateFieldDataWithRelative
no setter
hashCode int
The hash code for this object.
no setterinherited
hour DateFieldDataTime
no setter
minute DateFieldDataTime
no setter
monday DateFieldDataWithRelative
no setter
month DateFieldFullData
no setter
quarter DateFieldFullData
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturday DateFieldDataWithRelative
no setter
second DateFieldDataTime
no setter
sunday DateFieldDataWithRelative
no setter
thursday DateFieldDataWithRelative
no setter
tuesday DateFieldDataWithRelative
no setter
wednesday DateFieldDataWithRelative
no setter
week DateFieldFullData
no setter
weekday MultiLength
no setter
weekdayOfMonth MultiLength
no setter
weekOfMonth MultiLength
no setter
year DateFieldFullData
no setter
zone MultiLength
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited