TimeZones class abstract Timezones

Container for localized Timezone information.

Constructors

TimeZones(CommonLocaleData cld)
const

Properties

cld CommonLocaleData
Parent CommonLocaleData
final
fallbackFormat String
Localized message string for fallback format.
no setter
gmtFormat String
Localized message string for GMT formats.
no setter
gmtZeroFormat String
Localized message string for GMT=0 formats.
no setter
hashCode int
The hash code for this object.
no setterinherited
metaZoneNames Map<String, MetaZone>
Localized meta zone names.
no setter
negativeH String
Localized message string for negative offset timezone with whole hours only.
no setter
negativeHM String
Localized message string for negative offset timezone with hours and minutes.
no setter
negativeHMS String
Localized message string for negative offset timezone with hours minutes and seconds.
no setter
positiveH String
Localized message string for positive offset timezone with whole hours only.
no setter
positiveHM String
Localized message string for positive offset timezone with hours and minutes.
no setter
positiveHMS String
Localized message string for positive offset timezone with hours minutes and seconds.
no setter
regionFormat String
Localized message string for locale based format.
no setter
regionFormatDaylight String
Localized message string for locale based daylight savings format.
no setter
regionFormatStandard String
Localized message string for locale based standard format.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeZoneNames Map<String, TimeZoneNames>
Localized time zone names.
no setter

Methods

format(TimeZoneStyle style, Duration offset) String
Format the timezone offset in the desired style. For the formats that use a name, this format falls back to a numeric format.
get(String? code, {DateTime? dateTime}) TimeZone?
Get a timezone by the IANA/Olson code and optionally specify a dateTime. The dateTime is necessary as locations can be part of a different timezone during parts of their history. If no dateTime is specified the current date and time are assumed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String? code) TimeZone?
Get a timezone by the IANA/Olson code for the current date and time.