Unit class Units

Localized unit information.

Constructors

Unit({required UnitCountPattern long, required UnitCountPattern short, required UnitCountPattern narrow})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
long UnitCountPattern
Localized long unit information.
final
narrow UnitCountPattern
Localized narrow unit information.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short UnitCountPattern
Localized short unit information.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited